sqlobject.tests.test_aliases module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_aliases module

class `sqlobject.tests.test_aliases.` `JoinAlias`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = join_alias
  property `name`
  property `parent`
  `q` = join_alias
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_aliases.JoinAlias`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'join_alias'

`sqlobject.tests.test_aliases.` `test_1syntax`()

`sqlobject.tests.test_aliases.` `test_2perform_join`()

`sqlobject.tests.test_aliases.` `test_3joins`()